package com.ruoyi.buyerapi.service;

import java.util.List;
import com.ruoyi.buyerapi.domain.BuyerProjectMember;

/**
 * 立项管理成员Service接口
 * 
 * @author ruoyi
 * @date 2022-09-22
 */
public interface IBuyerProjectMemberService 
{
    /**
     * 查询立项管理成员
     * 
     * @param id 立项管理成员主键
     * @return 立项管理成员
     */
    public BuyerProjectMember selectBuyerProjectMemberById(String id);

    /**
     * 查询立项管理成员列表
     * 
     * @param buyerProjectMember 立项管理成员
     * @return 立项管理成员集合
     */
    public List<BuyerProjectMember> selectBuyerProjectMemberList(BuyerProjectMember buyerProjectMember);

    /**
     * 新增立项管理成员
     * 
     * @param buyerProjectMember 立项管理成员
     * @return 结果
     */
    public int insertBuyerProjectMember(BuyerProjectMember buyerProjectMember);

    /**
     * 修改立项管理成员
     * 
     * @param buyerProjectMember 立项管理成员
     * @return 结果
     */
    public int updateBuyerProjectMember(BuyerProjectMember buyerProjectMember);

    /**
     * 批量删除立项管理成员
     * 
     * @param ids 需要删除的立项管理成员主键集合
     * @return 结果
     */
    public int deleteBuyerProjectMemberByIds(String[] ids);

    /**
     * 删除立项管理成员信息
     * 
     * @param id 立项管理成员主键
     * @return 结果
     */
    public int deleteBuyerProjectMemberById(String id);
}
